@@ -154,7 +154,7 @@
 
 ;; closure struct in triggers of all the components
 (define-method (c:get-incoming-triggers-from-model (o <root>))
-  (delete-duplicates (append-map ast:required-out-triggers (filter (is? <component>) (ast:model* o)))
+  (delete-duplicates (append-map ast:requires-out-triggers (filter (is? <component>) (ast:model* o)))
                      (lambda (a b)
                        (and (equal? (c:model-parent-name a) (c:model-parent-name b))
                             (or (c:equal? ((compose ast:type .type .signature .event) a)
@@ -164,7 +164,7 @@
 
 ;; foreign closure struct and helper functions for foreign only
 (define-method (c:get-incoming-triggers-from-model (o <foreign>))
-  (delete-duplicates (ast:required-out-triggers o)
+  (delete-duplicates (ast:requires-out-triggers o)
                      (lambda (a b)
                        (and (equal? (c:model-parent-name a) (c:model-parent-name b))
                             (or (c:equal? ((compose ast:type .type .signature .event) a)
@@ -173,11 +173,11 @@
                                             ((compose .signature .event) b)))))))
 
 
-(define-method (c:binding-provided (o <binding>))
+(define-method (c:binding-provides (o <binding>))
   (if (ast:provides? (.port (.left o))) (.left o)
       (.right o)))
 
-(define-method (c:binding-required (o <binding>))
+(define-method (c:binding-requires (o <binding>))
   (if (ast:requires? (.port (.left o))) (.left o)
       (.right o)))
 
@@ -258,7 +258,7 @@
 
   (code-util:foreign-conflict? root)
 
-  (let ((root (code:om root)))
+  (let ((root (code:om+determinism root)))
     (let ((generator (code-util:indenter (cute x:header root)))
           (file-name (code-util:root-file-name root dir ".h")))
       (code-util:dump root generator #:file-name file-name))
