@@ -1,7 +1,7 @@
 ;;; Dezyne --- Dezyne command line tools
 ;;;
 ;;; Copyright © 2014, 2015, 2016, 2017, 2018, 2019, 2020, 2021, 2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
-;;; Copyright © 2017, 2018, 2021 Rutger van Beusekom <rutger@dezyne.org>
+;;; Copyright © 2017, 2018, 2021, 2022 Rutger van Beusekom <rutger@dezyne.org>
 ;;; Copyright © 2017, 2018, 2019 Rob Wieringa <rma.wieringa@gmail.com>
 ;;; Copyright © 2017 Johri van Eerd <vaneerd.johri@gmail.com>
 ;;; Copyright © 2018 Henk Katerberg <hank@mudball.nl>
@@ -46,10 +46,12 @@
   #:use-module (dzn templates)
 
   #:export (ast->dzn
+            dzn:blocking
+            dzn:comment
             dzn:data
+            dzn:define-type
             dzn:extension
             dzn:expression
-            dzn:indent
             dzn:expand-statement
             dzn:expression-expand
             dzn:action-arguments
@@ -59,7 +61,9 @@
             dzn:external
             dzn:formal-type
             dzn:global
+            dzn:import*
             dzn:injected
+            dzn:instance
             dzn:model
             dzn:model-name
             dzn:model-full-name
@@ -89,8 +93,10 @@
 
 (define-method (dzn:model (o <root>))
   (let* ((models (ast:model* o))
-         (models (filter (negate (disjoin (is? <type>) (is? <namespace>) ast:async?
-                                          (conjoin ast:imported? (negate (is? <foreign>)))))
+         (models (filter (negate (disjoin (is? <namespace>)
+                                          (is? <type>)
+                                          ast:async?
+                                          ast:imported?))
                          models))
          (models (ast:topological-model-sort models)))
     models))
@@ -101,14 +107,41 @@
 (define-method (dzn:model (o <ast>))
   o)
 
+
+;;;
+;;; Accessors
+;;;
+(define-method (dzn:comment (o <top>))
+  '())
+
+(define-method (dzn:comment (o <comment>))
+  (let ((str (.string o)))
+    (if (and (string? str) (not (string-null? str))) o
+        '())))
+
+(define-method (dzn:comment (o <locationed>))
+  (dzn:comment (.comment o)))
+
 (define-method (dzn:data (o <data>))
   (if (.value o) (.value o)
       '()))
 
+(define-method (dzn:import* (o <root>))
+  (filter (negate ast:imported?) (ast:import* o)))
+
+(define-method (dzn:instance (o <end-point>))
+  (if (not (.instance.name o)) '()
+      (list (.instance o))))
+
 
 ;;;
 ;;; Names
 ;;;
+(define-method (dzn:define-type (o <scope>))
+  (filter (conjoin (negate ast:imported?)
+                   (negate (is? <bool>))
+                   (negate (is? <void>)))
+          (ast:type* o)))
 
 (define-method (dzn:model-name (o <ast>))
   (ast:name (parent o <model>)))
@@ -140,7 +173,7 @@
   ((compose dzn:type .type .signature) o))
 
 (define-method (dzn:type (o <function>))
-  ((compose dzn:type .type .signature) o))
+  (dzn:type (.signature o)))
 
 (define-method (dzn:formal-type (o <formal>)) o)
 (define-method (dzn:formal-type (o <event>)) ((compose ast:formal* .signature) o))
@@ -222,6 +255,9 @@
 (define-method (dzn:statement (o <function>))
   (.statement o))
 
+(define-method (dzn:expand-statement (o <defer>))
+  (.statement o))
+
 (define-method (dzn:expand-statement (o <statement>))
   o)
 
@@ -239,6 +275,10 @@
 (define-method (dzn:expand-statement (o <blocking>))
   (.statement o))
 
+(define-method (dzn:expression (o <extern>))
+  (if (.value o) (.value o)
+      '()))
+
 (define-method (dzn:expand-statement (o <on>))
   (.statement o))
 
@@ -295,10 +335,6 @@
 (define-method (dzn:=expression (o <variable>))
   ((compose dzn:=expression .expression) o))
 
-(define-method (dzn:=expression (o <extern>))
-  (if (.value o) (.value o)
-      '()))
-
 
 ;;;
 ;;; Component
@@ -308,6 +344,10 @@
       (if (null? (ast:argument* o)) (list "")
           (ast:argument* o))))
 
+(define-method (dzn:blocking (o <port>))
+  (if (not (.blocking? o)) ""
+      o))
+
 (define-method (dzn:external (o <port>))
   (if (not (.external? o)) ""
       o))
