@@ -1,6 +1,6 @@
 ;;; Dezyne --- Dezyne command line tools
 ;;;
-;;; Copyright © 2014, 2015, 2017, 2019, 2020, 2021, 2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2014, 2015, 2017, 2019, 2020, 2021, 2022, 2023 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
 ;;; Copyright © 2017 Rutger van Beusekom <rutger@dezyne.org>
 ;;; Copyright © 2019 Rob Wieringa <rma.wieringa@gmail.com>
 ;;;
@@ -26,6 +26,7 @@
 (define-module (dzn code scheme)
   #:use-module (ice-9 receive)
   #:use-module (ice-9 match)
+  #:use-module (ice-9 string-fun)
   #:use-module (srfi srfi-1)
   #:use-module (srfi srfi-26)
 
@@ -87,14 +88,19 @@
     (scheme:sanitize-module-name
      (string-join (append namespace (list base-name)) " "))))
 
+(define-method (scheme:name (o <enum>))
+  (string-join (scheme:enum-name o) ":"))
+
 (define-method (scheme:names (o <interface>))
-  (let* ((name (scheme:class-name o))
+  (let* ((enums (code:enum-definer o))
+         (enums (map scheme:name enums))
+         (name (scheme:class-name o))
          (classes (map string->class-name
                        (list name
                              (string-append name ".in")
                              (string-append name ".out"))))
          (accessors (map (compose string->accessor .name) (ast:event* o))))
-    (append classes accessors)))
+    (append enums classes accessors)))
 
 (define-method (scheme:names (o <component-model>))
   (let* ((name (scheme:class-name o))
@@ -119,11 +125,14 @@
     (delete-duplicates (append-map scheme:names imported-models) string=?)))
 
 (define-method (scheme:exported-names (o <root>))
-  (let ((models (append (filter (conjoin (negate ast:imported?)
-                                         (negate (is? <foreign>)))
-                                (ast:model* o))
-                        (code:used-foreigns o))))
-    (delete-duplicates (append-map scheme:names models) string=?)))
+  (let* ((models (append (filter (conjoin (negate ast:imported?)
+                                          (negate (is? <foreign>)))
+                                 (ast:model* o))
+                         (code:used-foreigns o)))
+         (enums (code:global-enum-definer o))
+         (names (append (append-map scheme:names models)
+                        (map scheme:name enums))))
+    (delete-duplicates names string=?)))
 
 (define-method (scheme:export (o <root>))
   (let ((imports (scheme:imported-names o))
@@ -172,9 +181,10 @@
          (modules (map scheme:module-name models))
          (foreigns (map scheme:module-name (code:used-foreigns o)))
          (components (filter (is? <component>) (ast:model* o)))
-         (pump (if (or (pair? (append-map ast:async-port* components))
-                       (pair? (append-map (cut tree-collect (disjoin (is? <blocking>) (is? <blocking-compound>)) <>) components))) '("dzn pump") '())))
-    (map (cut make <file-name> #:name <>) (delete-duplicates (append pump modules foreigns)))))
+         (pump (if (code:pump? o) '("dzn pump")
+                   '()))
+         (files (delete-duplicates (append pump modules foreigns))))
+    (map (cut make <file-name> #:name <>) files)))
 
 (define-method (scheme:use-module (o <model>))
   (scheme:use-module (parent o <root>)))
@@ -198,12 +208,27 @@
   (let ((event (find (cut ast:name-equal? <> "clr") (ast:event* (.type o)))))
     (make <trigger> #:port.name (.name o) #:event.name (.name event) #:formals (ast:rescope ((compose .formals .signature) event)  (parent o <model>)))))
 
+(define (comment-mangler str prefix)
+  (let* ((str (string-replace-substring str "/*" ""))
+         (str (string-replace-substring str "*/" ""))
+         (lines (and str (string-split str #\newline)))
+         (lines (map (lambda (s)
+                       (if (not (string-prefix? "//" s)) s
+                           (substring s 2)))
+                     lines))
+         (lines (and str (map (cute string-append prefix <>) lines))))
+    (and str (string-join lines "\n"))))
+
+(define-method (scheme:mangle-comment (o <comment>))
+  (comment-mangler (.string o) ";;;"))
+
 (define (wrap-lonely-variable o)
   (match o
-    (($ <variable>) (make <compound> #:elements (list o)))
+    (($ <variable>)
+     (if (is-a? (.parent o) <compound>) o
+         (make <compound> #:elements (list o))))
     (($ <behavior>) (clone o #:statement (wrap-lonely-variable (.statement o))))
     (($ <component>) (clone o #:behavior (wrap-lonely-variable (.behavior o))))
-    ((and (? (is? <compound>)) (? ast:imperative?)) o)
     (($ <system>) o)
     (($ <foreign>) o)
     (($ <interface>) (clone o #:behavior (wrap-lonely-variable (.behavior o))))
