@@ -173,6 +173,12 @@
 (define-method (wfc (o <port>))
   (append
    (re-definition o)
+   (if (and (ast:provides? o) (ast:external? o))
+       `(,(wfc-error o (format #f "provides port `~a' cannot be external" (.name o))))
+       '())
+   (if (and (ast:provides? o) (ast:injected? o))
+       `(,(wfc-error o (format #f "provides port `~a' cannot be injected" (.name o))))
+       '())
    (if (ast:name-equal? (.name (parent o <model>)) (.name o))
        `(,(wfc-error o (format #f "port `~a' must not have the same name as the model it is defined in" (.name o))))
        '())
@@ -683,27 +689,33 @@
       (ast:equal? t1 t2)))
 
 (define-method (typed-expression (o <expression>) (type <class>))
-  (let* ((expr-wfc (wfc o))
-         (expr-type (ast:type o)))
-    (cond ((pair? expr-wfc) expr-wfc)
-          ((not expr-type)
-           `(,(wfc-error o (format #f "undefined identifier `~a'" (.name o)))))
-          ((not (is-a? expr-type type))
-           `(,(wfc-error o (format #f "~a expression expected" (class-name type)))))
-          (else '()))))
+  (or (as (wfc o) <pair>)
+      (let ((expr-type (ast:type o)))
+        (cond
+         ((and (not expr-type)
+               (not (is-a? o <named>)))
+          `(,(wfc-error o (format #f "typed expression expected `~a'" (ast-name o)))))
+         ((not expr-type)
+          `(,(wfc-error o (format #f "undefined identifier `~a'" (.name o)))))
+         ((not (is-a? expr-type type))
+          `(,(wfc-error o (format #f "~a expression expected" (class-name type)))))
+         (else '())))))
 
 (define-method (no-extern-expression (o <expression>))
-  (let* ((expr-wfc (wfc o))
-         (expr-type (ast:type o)))
-    (cond ((pair? expr-wfc) expr-wfc)
-          ((not expr-type)
-           `(,(wfc-error o (format #f "undefined identifier `~a'" (.name o)))))
-          ((is-a? expr-type <extern>)
-           `(,(wfc-error
-               o
-               (format #f "extern data-type `~a' expression in binary operator"
-                       (type-name expr-type)))))
-          (else '()))))
+  (or (as (wfc o) <pair>)
+      (let ((type (ast:type o)))
+        (cond
+         ((and (not type)
+               (not (is-a? type <named>)))
+          `(,(wfc-error o (format #f "typed expression expected `~a'" (ast-name o)))))
+         ((not type)
+          `(,(wfc-error o (format #f "undefined identifier `~a'" (.name o)))))
+         ((is-a? type <extern>)
+          `(,(wfc-error
+              o
+              (format #f "extern data-type `~a' expression in binary operator"
+                      (type-name type)))))
+         (else '())))))
 
 (define-method (wfc (o <not>))
   (typed-expression (.expression o) <bool>))
@@ -831,37 +843,46 @@
 
 (define-method (re-definition (o <declaration>))
   (let* ((name (ast:name o))
-         (scope (parent (.parent o) <scope>))
-         (previous (and scope (ast:lookup scope name)))
-         (previous-scope (and previous (parent (.parent previous) <scope>))))
-    (if (and scope
-             previous
-             (ast:eq? scope previous-scope)
-             (not (ast:eq? previous o))
-             (not (is-a? previous <namespace>)))
-        `(,(wfc-error o (format #f "identifier `~a' defined before" (ast:name o)))
-          ,(wfc-info previous (format #f "previous `~a' definition here" (ast:name previous))))
-        '())))
+         (scope (parent (.parent o) <scope>)))
+    (define (get-previous scope)
+      (let ((previous (and scope (ast:lookup scope name))))
+        (cond ((not (ast:eq? previous o))
+               previous)
+              (else
+               (get-previous (parent (.parent scope) <scope>))))))
+    (let* ((previous (get-previous scope))
+           (previous-scope (and previous (parent (.parent previous) <scope>))))
+      (if (and previous
+               (or (ast:eq? scope previous-scope)
+                   (and (is-a? previous <type>)
+                        (not (is-a? o <type>))))
+               (not (ast:eq? previous o))
+               (not (is-a? previous <namespace>)))
+          `(,(wfc-error o (format #f "identifier `~a' defined before" (ast:name o)))
+            ,(wfc-info previous (format #f "previous `~a' definition here" (ast:name previous))))
+          '()))))
 
 (define-method (assign (o <ast>))
-  (let* ((assign-type (ast:type o))
-         (expression (.expression o))
-         (wfce (wfc expression))
-         (expression-type (ast:type expression)))
-    (cond ((pair? wfce) wfce)
-          ((not expression-type)
-           `(,(wfc-error o (format #f "undefined identifier `~a'" (.name expression)))))
-          ((and (not assign-type) (is-a? o <variable>))
-           `(,(wfc-error o (format #f "unknown type name `~a'" (type-name (.type.name o))))))
-          ((and (is-a? o <variable>) (is-a? expression-type <void>))
-           (if (is-a? assign-type <extern>) '()
-               `(,(wfc-error o (format #f "uninitialized variable `~a'" (.name o))))))
-          ((not assign-type) '()) ;; reported before
-          ((not (equal-type? expression-type assign-type))
-           `(,(wfc-error o (format #f "type mismatch: expected `~a', found: `~a'"
-                                   (type-name assign-type)
-                                   (type-name expression-type)))))
-          (else '()))))
+  (or (as (wfc (.expression o)) <pair>)
+      (let* ((assign-type (ast:type o))
+             (expression (.expression o))
+             (expression-type (ast:type expression))
+             (variable (or (as o <variable>)
+                           (.variable o))))
+        (cond
+         ((and (not assign-type) (is-a? variable <variable>))
+          `(,(wfc-error o (format #f "unknown type name `~a'"
+                                  (type-name (.type.name variable))))))
+         ((and (not expression-type) (is-a? expression <named>))
+          `(,(wfc-error o (format #f "undefined identifier `~a'" (.name expression)))))
+         ((and (is-a? o <variable>) (is-a? expression-type <void>))
+          (if (is-a? assign-type <extern>) '()
+              `(,(wfc-error o (format #f "uninitialized variable `~a'" (.name o))))))
+         ((not (equal-type? expression-type assign-type))
+          `(,(wfc-error o (format #f "type mismatch: expected `~a', found: `~a'"
+                                  (type-name assign-type)
+                                  (type-name expression-type)))))
+         (else '())))))
 
 (define-method (type-name (o <boolean>))
   "<unknown type>")
@@ -1127,6 +1148,8 @@
     (ast:eq? s (.statement o)))
   (define (step o continuation)
     (cond
+     ((is-a? o <illegal>)
+      '())
      ((is-a? o <return>)
       (list o))
      ((function-body? continuation)
@@ -1181,9 +1204,12 @@
      ((and (not (is-a? (ast:type o) <void>))
            (or (is-a? p <compound>)
                (is-a? p <guard>)
-               (is-a? p <on>)))
+               (is-a? p <on>)
+               (and (is-a? p <if>)
+                    (not (ast:eq? o (.expression p))))))
       `(,(wfc-error o (format #f "~a value discarded" class))))
-     (else '()))))
+     (else
+      '()))))
 
 (define-method (imperative-context (o <ast>))
   (let* ((p (.parent o))
