@@ -102,12 +102,14 @@ namespace dzn
             public Component deferred;
             public Queue<Action> q;
             public bool flushes;
+            public Object skip;
             public State()
             {
                 this.handling = 0;
                 this.blocked = 0;
                 this.q = new Queue<Action>();
                 this.flushes = false;
+                this.skip = null;
             }
         }
 
@@ -185,8 +187,21 @@ namespace dzn
             states[c].handling = coroutine_id;
             f();
         }
+        public bool skip_block(Object c, Object p)
+        {
+            return states[c].skip == p;
+        }
+        public void set_skip_block(Object c, Object p)
+        {
+            states[c].skip = p;
+        }
+        public void reset_skip_block(Object c)
+        {
+            states[c].skip = null;
+        }
         public void call_in(Component c, Action f, Port p, String e)
         {
+            reset_skip_block(c);
             if(states[c].handling != 0 || dzn.pump.port_blocked_p(c.dzn_locator, p))
             {
               dzn.pump.collateral_block(c, c.dzn_locator);
@@ -200,6 +215,7 @@ namespace dzn
         }
         public R call_in<R>(Component c, Func<R> f, Port p, String e) where R : struct, IComparable, IConvertible
         {
+            reset_skip_block(c);
             if(states[c].handling != 0 || dzn.pump.port_blocked_p(c.dzn_locator, p))
             {
               dzn.pump.collateral_block(c, c.dzn_locator);
